@@ -1,7 +1,7 @@
 """
     AwesomeTkinter, a new tkinter widgets design using custom styles and images
 
-    :copyright: (c) 2020 by Mahmoud Elshahat.
+    :copyright: (c) 2020-2021 by Mahmoud Elshahat.
 
 """
 
@@ -26,7 +26,8 @@ class ScrollableFrame(tk.Frame):
         tk.Label(frame, text=hello).pack()
     """
 
-    def __init__(self, parent, vscroll=True, hscroll=True, autoscroll=False, bg=None, sbar_fg=None, sbar_bg=None):
+    def __init__(self, parent, vscroll=True, hscroll=True, autoscroll=False, bg=None, sbar_fg=None, sbar_bg=None,
+                 vbar_width=10, hbar_width=10):
         """initialize
 
         Args:
@@ -37,9 +38,11 @@ class ScrollableFrame(tk.Frame):
             bg (str): background
             sbar_fg (str): color of scrollbars' slider
             sbar_bg (str): color of scrollbars' trough, default to frame's background
+            vbar_width (int): vertical scrollbar width
+            hbar_width (int): horizontal scrollbar width
         """
         self.autoscroll = autoscroll
-        self.last_height_value = None
+        self.current_height = None
 
         sbar_bg = sbar_bg or 'white'
         sbar_fg = sbar_fg or 'blue'
@@ -55,12 +58,14 @@ class ScrollableFrame(tk.Frame):
 
         # scrollbars
         if vscroll:
-            self.vsb = SimpleScrollbar(self.outer_frame, orient="vertical", command=self.canvas.yview, bg=sbar_bg, slider_color=sbar_fg)
+            self.vsb = SimpleScrollbar(self.outer_frame, orient="vertical", command=self.canvas.yview, bg=sbar_bg,
+                                       slider_color=sbar_fg, width=vbar_width)
             self.canvas.configure(yscrollcommand=self.vsb.set)
 
             self.vsb.pack(side="right", fill="y")
         if hscroll:
-            self.hsb = SimpleScrollbar(self.outer_frame, orient="horizontal", command=self.canvas.xview, bg=sbar_bg, slider_color=sbar_fg)
+            self.hsb = SimpleScrollbar(self.outer_frame, orient="horizontal", command=self.canvas.xview, bg=sbar_bg,
+                                       slider_color=sbar_fg, width=hbar_width)
             self.canvas.configure(xscrollcommand=self.hsb.set)
 
             self.hsb.pack(side="bottom", fill="x")
@@ -94,13 +99,14 @@ class ScrollableFrame(tk.Frame):
 
     def _on_self_configure(self, event):
         """Reset the scroll region to match contents"""
-        self.canvas.configure(scrollregion=self.canvas.bbox("all"))
-        self.update_idletasks()
+        if self.winfo_height() != self.current_height:
+            self.canvas.configure(scrollregion=self.canvas.bbox("all"))
 
-        # scroll to bottom
-        if self.autoscroll and self.last_height_value != self.winfo_height():
-            self.last_height_value = self.winfo_height()
-            self.scrolltobottom()
+            # scroll to bottom, if new widgets added to frame
+            if self.autoscroll:
+                self.scrolltobottom()
+
+            self.current_height = self.winfo_height()
 
     def _on_canvas_configure(self, event):
         """expand self to fill canvas"""
